theme

package
v0.5.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 1, 2026 License: MIT Imports: 1 Imported by: 0

Documentation

Index

Constants

const (
	ColorOK   = "#9ece6a"
	ColorWarn = "#e0af68"
	ColorCrit = "#f7768e"
	ColorAxis = "#565f89"
)

Percentage value threshold colors.

Variables

var SeriesPalette = []string{
	"#9ece6a",
	"#7aa2f7",
	"#bb9af7",
	"#7dcfff",
	"#e0af68",
	"#f7768e",
}

SeriesPalette defines series colors in Tokyo Night palette order.

Functions

func SeriesColor

func SeriesColor(i int) string

SeriesColor returns the color for series i, cycling through the palette.

func ValueColor

func ValueColor(v float64) string

ValueColor returns a color based on thresholds: <60 OK, <85 warn, otherwise crit.

Types

type Preset

type Preset struct {
	Axis lipgloss.Style
}

Preset holds chart styling options.

func TokyoNight

func TokyoNight() Preset

TokyoNight returns a preset in Tokyo Night palette.

func (Preset) LineFor

func (p Preset) LineFor(v float64) lipgloss.Style

LineFor returns line style for the current value based on thresholds.

Jump to